==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/mixin/entity/AnimalEntityMixin.java <==
package cc.thonly.reverie_dreams.mixin.entity;

import cc.thonly.reverie_dreams.interfaces.IAnimalEntity;
import net.minecraft.class_10131;
import net.minecraft.class_1268;
import net.minecraft.class_1296;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1429;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_6024;
import net.minecraft.class_9334;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.Unique;

@Mixin(class_1429.class)
public abstract class AnimalEntityMixin extends class_1296 implements IAnimalEntity {

    @Shadow private int loveTicks;

    protected AnimalEntityMixin(class_1299<? extends class_1296> entityType, class_1937 world) {
        super(entityType, world);
    }

    @Unique
    @Override
    public void eatStackFood(class_1309 livingEntity, class_1268 hand, class_1799 stack) {
        int i = stack.method_7947();
        class_10131 useRemainderComponent = stack.method_58694(class_9334.field_53965);
        stack.method_7934(1);
        if (useRemainderComponent != null) {
            class_1799 itemStack = useRemainderComponent.method_62863(stack, i, false, livingEntity::method_64399);
            livingEntity.method_6122(hand, itemStack);
        }
    }

    @Unique
    @Override
    public void loveEntity(@Nullable class_1309 entity) {
        this.loveTicks = 600;
        this.method_37908().method_8421(this, class_6024.field_30043);
    }
}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/mixin/entity/AnimalEntityMixin.java <==
package cc.thonly.reverie_dreams.mixin.entity;

import cc.thonly.reverie_dreams.interfaces.IAnimalEntity;
import net.minecraft.class_10131;
import net.minecraft.class_1268;
import net.minecraft.class_1296;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1429;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_6024;
import net.minecraft.class_9334;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.Unique;

@Mixin(class_1429.class)
public abstract class AnimalEntityMixin extends class_1296 implements IAnimalEntity {

    @Shadow private int inLove;

    protected AnimalEntityMixin(class_1299<? extends class_1296> entityType, class_1937 world) {
        super(entityType, world);
    }

    @Unique
    @Override
    public void eatStackFood(class_1309 livingEntity, class_1268 hand, class_1799 stack) {
        int i = stack.method_7947();
        class_10131 useRemainderComponent = stack.method_58694(class_9334.field_53965);
        stack.method_7934(1);
        if (useRemainderComponent != null) {
            class_1799 itemStack = useRemainderComponent.method_62863(stack, i, false, livingEntity::method_64399);
            livingEntity.method_6122(hand, itemStack);
        }
    }

    @Unique
    @Override
    public void loveEntity(@Nullable class_1309 entity) {
        this.inLove = 600;
        this.method_37908().method_8421(this, class_6024.field_30043);
    }
}
